#' ftRename
#'
#' @param data A flowering time data frame
#' @param species Either "Medicago" (default) of "Arabidopsis"
#' @description A helper function which renames my flowering time datasets
#' @export
ftRename <- function(data, species = "Medicago"){

  require(checkmate)
  require(dplyr)

  assertChoice(species, c("Medicago", "Arabidopsis"))

  if(species == "Medicago"){

    assertNames(names(data), identical.to =  c("Sowing_Number", "Conditions", "Genotype", "Individual", "Plant_Number",
                                               "Date_Sown", "Date_Flowered", "Number_of_Days_to_First_Floral_Bud",
                                               "Position_of_1st_Floral_Bud", "Node_Number_of_Main_Axis_at_1st_Floral_Bud",
                                               "Comments", "Mutant"),
                .var.name = "data")

    data <- rename(data,
                   sowing_number = .data$Sowing_Number,
                   conditions = .data$Conditions,
                   genotype = .data$Genotype,
                   individual = .data$Individual,
                   plant_num = .data$Plant_Number,
                   sowing_date = .data$Date_Sown,
                   flowering_date = .data$Date_Flowered,
                   days_to_flower = .data$Number_of_Days_to_First_Floral_Bud,
                   first_bud_loc = .data$Position_of_1st_Floral_Bud,
                   node_num = .data$Node_Number_of_Main_Axis_at_1st_Floral_Bud,
                   comments = .data$Comments,
                   mutant = .data$Mutant)
  }
  else if(species == "Arabidopsis"){

    assertNames(names(data), identical.to =  c("Sowing_Number", "Conditions", "Genotype", "Individual", "Plant_Number", "Date_Sown", "Date_Flowered",
                                               "Days_to_Flower", "Rosette_leaf_Number", "Cauline_leaf_Number",
                                               "Total_Leaves", "Comments", "Mutant"),
                .var.name = "data")

    data <- rename(data,
                   sowing_number = .data$Sowing_Number,
                   conditions = .data$Conditions,
                   genotype = .data$Genotype,
                   individual = .data$Individual,
                   plant_num = .data$Plant_Number,
                   sowing_date = .data$Date_Sown,
                   flowering_date = .data$Date_Flowered,
                   days_to_flower = .data$Days_to_Flower,
                   rosette_leaves = .data$Rosette_leaf_Number,
                   cauline_leaves = .data$Cauline_leaf_Number,
                   total_leaves = .data$Total_Leaves,
                   comments = .data$Comments,
                   mutant = .data$Mutant)
  }

  return(data)
}
